# Request Summary
(Summarize your idea or feature you request)

# Use case
(Explain how this would affect the experience with ioproc)

# Images / Sketches
(If possible, please provide some screenshots or sketches to describe your idea even better)

# Other
(Feel free to add any information you think is relevant in order to adress this request)

/label ~feature-request
